@@ -1,12 +1,13 @@
 import json
 import os.path as osp
+from functools import partial
 from itertools import repeat
 from pathlib import Path
 from typing import Dict, List, Set, Tuple, Union
 
 from tqdm.contrib.concurrent import process_map
 
-from zod.constants import SEQUENCES, TRAIN, TRAINVAL_FILES, VAL, VERSIONS
+from zod.constants import FULL, SEQUENCES, TRAIN, TRAINVAL_FILES, VAL, VERSIONS
 from zod.data_classes.info import Information
 from zod.data_classes.sequence import ZodSequence
 from zod.utils.utils import zfill_id
@@ -21,9 +22,10 @@ def _create_sequence(sequence: dict, dataset_root: str) -> Information:
 class ZodSequences:
     """ZOD Sequences."""
 
-    def __init__(self, dataset_root: Union[Path, str], version: str):
+    def __init__(self, dataset_root: Union[Path, str], version: str, mp: bool = True):
         self._dataset_root = dataset_root
         self._version = version
+        self._mp = mp
         assert version in VERSIONS, f"Unknown version: {version}, must be one of: {VERSIONS}"
         self._train_sequences, self._val_sequences = self._load_sequences()
         self._sequences: Dict[str, Information] = {
@@ -49,27 +51,28 @@ class ZodSequences:
     def _load_sequences(self) -> Tuple[Dict[str, Information], Dict[str, Information]]:
         """Load sequences for the given version."""
         filename = TRAINVAL_FILES[SEQUENCES][self._version]
-
         with open(osp.join(self._dataset_root, filename), "r") as f:
             all_ids = json.load(f)
 
-        train_sequences = process_map(
-            _create_sequence,
-            all_ids[TRAIN],
-            repeat(self._dataset_root),
-            chunksize=1,
-            desc="Loading train sequences",
-        )
-        val_sequences = process_map(
-            _create_sequence,
-            all_ids[VAL],
-            repeat(self._dataset_root),
-            chunksize=1,
-            desc="Loading val sequences",
-        )
-
-        train_sequences = {s.id: s for s in train_sequences}
-        val_sequences = {s.id: s for s in val_sequences}
+        func = partial(_create_sequence, dataset_root=self._dataset_root)
+        if self._mp and self._version == FULL:
+            train_sequences = process_map(
+                func,
+                all_ids[TRAIN],
+                desc="Loading train sequences",
+                chunksize=10 if self._version == FULL else 1,
+            )
+            val_sequences = process_map(
+                func,
+                all_ids[VAL],
+                desc="Loading val sequences",
+                chunksize=10 if self._version == FULL else 1,
+            )
+            train_sequences = {s.id: s for s in train_sequences}
+            val_sequences = {s.id: s for s in val_sequences}
+        else:
+            train_sequences = {s.id: s for s in map(func, all_ids[TRAIN])}
+            val_sequences = {s.id: s for s in map(func, all_ids[VAL])}
 
         return train_sequences, val_sequences
 
